A (very) minimal wrapper of:

- typechecking [beartype](https://github.com/beartype/)
- shapechecking [jaxtyping](https://github.com/google/jaxtyping)
- dispatch [plum](https://github.com/beartype/plum)
